@@ -1,6 +1,6 @@
 import test from 'ava'
 
-import { js, parseFiles, ts, tsx } from '../index'
+import { js, parseFiles, ts, tsx, html } from '../index'
 const { parse, kind } = js
 let parseMulti = countedPromise(parseFiles)
 
@@ -149,6 +149,25 @@ test('test file count', async t => {
   t.is(i, fileCount)
 })
 
+test('test languageGlobs', async t => {
+  let i = 0
+  let foundVue = false
+  let fileCount = await parseMulti({
+    paths: ['./'],
+    languageGlobs: {
+      'html': ['*.vue']
+    },
+  }, (err, root) => {
+    t.is(err, null)
+    if (root.filename().endsWith('.vue')) {
+      foundVue = true
+    }
+    i++
+  })
+  t.is(i, fileCount)
+  t.true(foundVue)
+})
+
 test('show good error message for invalid arg', async t => {
   const sg = parse('console.log(123)')
   t.throws(() => sg.root().find({rule: {regex: '('}}), {
@@ -204,6 +223,39 @@ test('tsx should not find ts file', async t => {
   t.assert(true)
 })
 
+test('find with language globs', async t => {
+  let findInFiles = countedPromise(tsx.findInFiles)
+  await findInFiles({
+    paths: ['./'],
+    matcher: {
+      rule: {kind: 'member_expression'},
+    },
+    languageGlobs: ['*.ts'],
+  }, (err, n) => {
+    t.is(err, null)
+    const root = n[0].getRoot();
+    t.is(root.filename().replace('\\', '/'), './__test__/index.spec.ts')
+  })
+})
+
+test('find with language globs can parse with correct language', async t => {
+  let findInFiles = countedPromise(html.findInFiles)
+  await findInFiles({
+    paths: ['./'],
+    matcher: {
+      rule: {pattern: '<template>$A</template>'},
+    },
+    languageGlobs: ['*.vue'],
+  }, (err, n) => {
+    t.is(err, null)
+    const root = n[0].getRoot();
+    t.is(root.filename().replace('\\', '/'), './__test__/test.vue')
+    const div = root.root().find('<h1>$A</h1>')?.getMatch('A')?.text()
+    t.is(div, '{{ greeting }}')
+  })
+})
+
+
 function countedPromise<F extends (t: any, cb: any) => Promise<number>>(func: F) {
   type P = Parameters<F>
   return async (t: P[0], cb: P[1]) => {
